==> Java-Swing-0.03.tar.gz: Java-Swing-0.03/java/PerlMenuDragMouseListener.java <==
import javax.swing.event.MenuDragMouseListener;
import org.perl.inline.java.*;

public class      PerlMenuDragMouseListener
       extends    InlineJavaPerlCaller
       implements MenuDragMouseListener
{
    String sender;
    String callbacks;

    public PerlMenuDragMouseListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void menuDragMouseEntered(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuDragMouseListener",
                "_MenuDragMouseListener",
                new Object[] {sender, callbacks, "menuDragMouseEntered", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuDragMouseExited(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuDragMouseListener",
                "_MenuDragMouseListener",
                new Object[] {sender, callbacks, "menuDragMouseExited", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuDragMouseDragged(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuDragMouseListener",
                "_MenuDragMouseListener",
                new Object[] {sender, callbacks, "menuDragMouseDragged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuDragMouseReleased(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuDragMouseListener",
                "_MenuDragMouseListener",
                new Object[] {sender, callbacks, "menuDragMouseReleased", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.14.tar.gz: Java-Swing-0.14/java/PerlMenuDragMouseListener.java <==
import javax.swing.event.MenuDragMouseListener;
import org.perl.inline.java.*;

public class      PerlMenuDragMouseListener
       extends    InlineJavaPerlCaller
       implements MenuDragMouseListener
{
    String sender;
    String callbacks;

    public PerlMenuDragMouseListener() throws InlineJavaException { }

    public PerlMenuDragMouseListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void menuDragMouseEntered(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuDragMouseEntered", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuDragMouseExited(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuDragMouseExited", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuDragMouseDragged(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuDragMouseDragged", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuDragMouseReleased(javax.swing.event.MenuDragMouseEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuDragMouseReleased", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
